#!/usr/bin/env python3

import sys
import os

try:
    import fastnlo as fnlo
except ModuleNotFoundError:
    print("fastNLO Python extension not found")
    sys.exit(77)

LIBDIR = os.environ["LIBDIR"]

TYPES = ["fix", "flex"]
NAMES = ["NodesPerBin", "NodeDensity"]
SEEDS = [1000, 2000]

# fnlo.SetGlobalVerbosity(fnlo.DEBUG)

os.system("rm -rf output")
os.system("ln -s input/InclusiveNJets_InclusiveJets_fix.wrm")
os.system("ln -s input/InclusiveNJets_InclusiveJets_flex.wrm")


def generate_table(vartype: str, name: str, seed: int):
    os.system(f"ln -sf input/{vartype}_{name}.str InclusiveNJets.str")
    print(f"Asserting that steering file InclusiveNJets.str exists")
    assert os.path.exists("InclusiveNJets.str")
    os.system(
        "nlojet++ "
        "--calculate "
        "-c born "
        f"-s {seed} "
        f"--name {vartype}_{name}_{seed:06d} "
        f" -u {LIBDIR}/fastnlo_interface_nlojet/libInclusiveNJets.la "
        "--max-event 10000 "
        "--save-after 10000 "
    )
    expected_outfile = "output/run-hhc-born-2jet.tab.gz"
    print(f"Asserting that there is a table under {expected_outfile}")
    assert os.path.exists(expected_outfile)
    os.system(f"mv {expected_outfile} output/{vartype}_{name}_{seed:06d}.tab.gz")


for vartype in TYPES:
    for steering_file in NAMES:
        for seed in SEEDS:
            generate_table(vartype, steering_file, seed)
        os.system(f"fnlo-tk-merge2 output/{vartype}_{steering_file}_??????.tab.gz "
                  f"output/{vartype}_{steering_file}_merged.tab.gz")

    for seed in SEEDS:
        filename_0 = f"output/{vartype}_{NAMES[0]}_{seed:06d}.tab.gz"
        filename_1 = f"output/{vartype}_{NAMES[1]}_{seed:06d}.tab.gz"
        table_0 = fnlo.fastNLOTable(filename_0)
        table_1 = fnlo.fastNLOTable(filename_1)
        print(f"Asserting equal: {filename_0} <-> {filename_1}")
        assert table_0.IsEquivalent(table_1, 1e-8)

    filename_0 = f"output/{vartype}_{NAMES[0]}_merged.tab.gz"
    filename_1 = f"output/{vartype}_{NAMES[1]}_merged.tab.gz"
    table_0_merged = fnlo.fastNLOTable(filename_0)
    table_1_merged = fnlo.fastNLOTable(filename_1)
    print(f"Asserting equal: {filename_0} <-> {filename_1}")
    assert table_0_merged.IsEquivalent(table_1_merged, 1e-8)
